package X3D::FieldTypes::MFFloat;

our $VERSION = '0.009';

use X3D::Package 'MFFloat : MFDouble { [] }';

1;
__END__
